@@ -67,7 +67,7 @@ test_that("title", {
   unlink(file.path(tdir, "shiny"), recursive = TRUE)
 })
 
-test_that("order tabs", {
+test_that("panelStructure argument works", {
   skip_on_cran()
   # create mock cdm
   set.seed(123456)
@@ -93,122 +93,83 @@ test_that("order tabs", {
       CohortCharacteristics::summariseCohortOverlap()
   )
 
-  # generate shiny
   tdir <- tempdir()
+
+  # default panelDetails
+  panelDetails <- panelDetailsFromResult(result) |>
+    populatePanelDetailsOptions(result)
+  panels <- writeUiPanels(panelDetails)
+
+  # default panelStructure
+  panelStructure <- as.list(names(panelDetails))
+  uiPanels <- structurePanels(panels, panelStructure)
+  order <- panels |>
+    purrr::map_int(\(x) {
+      stringr::str_locate(string = uiPanels, pattern = stringr::fixed(x)) |>
+        dplyr::as_tibble() |>
+        dplyr::pull("start")
+    }) |>
+    sort() |>
+    names()
+  expect_identical(unlist(panelStructure), order)
+
+  # custom panel order
+  panelStructure <- list("summarise_cohort_count", "summarise_cohort_overlap", "summarise_cohort_attrition")
+  uiPanels <- structurePanels(panels, panelStructure)
+  order <- panels |>
+    purrr::map_int(\(x) {
+      stringr::str_locate(string = uiPanels, pattern = stringr::fixed(x)) |>
+        dplyr::as_tibble() |>
+        dplyr::pull("start")
+    }) |>
+    sort() |>
+    names()
+  expect_identical(unlist(panelStructure), order)
+
+  # dropdown menu
+  panelStructure <- list(
+    "Panel details" = c("summarise_cohort_count", "summarise_cohort_attrition"),
+    "summarise_cohort_overlap"
+  )
+  uiPanels <- structurePanels(panels, panelStructure)
+  order <- panels |>
+    purrr::map_int(\(x) {
+      stringr::str_locate(string = uiPanels, pattern = stringr::fixed(x)) |>
+        dplyr::as_tibble() |>
+        dplyr::pull("start")
+    }) |>
+    sort() |>
+    names()
+  expect_identical(unname(unlist(panelStructure)), order)
   expect_no_error(exportStaticApp(
     result = result,
     directory = tdir,
-    panelStructure = list(
-      "summarise_cohort_count",
-      "summarise_cohort_overlap",
-      "summarise_cohort_attrition"
-    )
+    panelDetails = panelDetailsFromResult(result),
+    panelStructure = panelStructure
   ))
-
-  # snapshot ui
-  ui <- readLines(file.path(tdir, "shiny", "ui.R"))
-  expect_snapshot(cat(ui, sep = "\n"))
-
-  # delete created shiny
+  expect_true("shiny" %in% list.files(tdir))
   unlink(file.path(tdir, "shiny"), recursive = TRUE)
 
-  # expect warning if panel is not present
-  expect_warning(exportStaticApp(
-    result = result,
-    directory = tdir,
-    panelStructure = list(
-      "summarise_cohort_count", "summarise_cohort_attrition",
-      "summarise_cohort_overlap", "not an option",
-      "another missing result"
-    )
-  ))
+  panels <- c("summarise_cohort_count", "summarise_cohort_overlap", "summarise_cohort_attrition")
 
-  # delete created shiny
-  unlink(file.path(tdir, "shiny"), recursive = TRUE)
+  # panel present in details but not in structure
+  panelStructure <- list("summarise_cohort_count", "summarise_cohort_overlap")
+  expect_warning(panelStructure <- validatePanelStructure(panelStructure, panels))
+  expect_identical(panelStructure, as.list(panels))
 
-  # expect warning if panel is not present
-  expect_warning(exportStaticApp(
-    result = result, directory = tdir, panelStructure = list("not an option")
-  ))
+  # panel present in structure but not in details
+  panelStructure <- list("summarise_cohort_count", "summarise_cohort_overlap", "summarise_cohort_attrition", "not_present")
+  expect_warning(panelStructure <- validatePanelStructure(panelStructure, panels))
+  expect_identical(panelStructure, as.list(panels))
 
-  # delete created shiny
-  unlink(file.path(tdir, "shiny"), recursive = TRUE)
-
-  # menu with results not in result
-  expect_warning(exportStaticApp(
-    result = result,
-    directory = tdir,
-    panelStructure = list(
-      "CHARACTERISTICS" = c("summarise_characteristics", "summarise_large_scale_characteristics", "hi"),
-      "summarise_cohort_overlap"
-    )
-  ))
-
-  # snapshot ui
-  ui <- readLines(file.path(tdir, "shiny", "ui.R"))
-  expect_snapshot(cat(ui, sep = "\n"))
-
-  # delete created shiny
-  unlink(file.path(tdir, "shiny"), recursive = TRUE)
-
-  # menu for details
-  expect_no_error(exportStaticApp(
-    result = result,
-    directory = tdir,
-    panelStructure = list(
-      "DETAILS" = c("summarise_cohort_count", "summarise_cohort_attrition"),
-      "summarise_cohort_overlap"
-    ),
-    panelDetails = list(
-      "summarise_cohort_attrition" = list(
-        result_type = "summarise_cohort_attrition",
-        title = "Attrition"
-      ),
-      "summarise_cohort_overlap" = list(
-        result_type = "summarise_cohort_overlap",
-        title = "Overlap"
-      )
-    )
-  ))
-
-  # snapshot ui
-  ui <- readLines(file.path(tdir, "shiny", "ui.R"))
-  expect_snapshot(cat(ui, sep = "\n"))
-
-  # delete created shiny
-  unlink(file.path(tdir, "shiny"), recursive = TRUE)
-
-  # expect error if it is not a list
-  expect_error(exportStaticApp(result = result, directory = tdir, panelStructure = c("must be a list")))
-
-  # expect error if duplicated elements
-  expect_error(exportStaticApp(result = result, directory = tdir, panelStructure = list(
-    "summarise_cohort_overlap", "summarise_cohort_overlap")))
 })
 
 test_that("theme", {
-  tdir <- tempdir()
+  # no theme
+  expect_identical(validateTheme(NULL), omopViewerThemes$default)
 
-  expect_no_error(exportStaticApp(
-    result = omopgenerics::emptySummarisedResult(),
-    directory = tdir,
-    theme = "theme1",
-    open = FALSE
-  ))
-
-  ui <- readLines(file.path(tdir, "shiny", "ui.R")) |>
-    stringr::str_flatten() |>
-    stringr::str_replace_all(" ", "") |>
-    stringr::str_replace_all('"', "'")
-
-  expectedTheme <- omopViewerThemes$theme1 |>
-    stringr::str_replace_all("\n| ", "") |>
-    stringr::str_replace_all('"', "'")
-
-  expect_true(grepl(expectedTheme, ui, fixed = TRUE))
-
-  # delete created shiny
-  unlink(file.path(tdir, "shiny"), recursive = TRUE)
+  # us a pre build theme
+  expect_identical(validateTheme("theme1"), omopViewerThemes$theme1)
 
   # custom theme
   theme <- "bslib::bs_theme(bootswatch = 'sandstone',
@@ -218,99 +179,34 @@ test_that("theme", {
     success = '#3B9AB2',
     base_font = bslib::font_google('Space Mono'),
     code_font = bslib::font_google('Space Mono'))"
+  expect_identical(validateTheme(theme), theme)
 
-  expect_message(exportStaticApp(
-    result = omopgenerics::emptySummarisedResult(),
-    theme = theme,
-    directory = tdir,
-    open = FALSE
-  ))
-
-  ui <- readLines(file.path(tdir, "shiny", "ui.R")) |>
-    stringr::str_flatten() |>
-    stringr::str_replace_all(" ", "") |>
-    stringr::str_replace_all('"', "'")
-
-  expectedTheme <- theme |>
-    stringr::str_replace_all("\n| ", "") |>
-    stringr::str_replace_all('"', "'")
-
-  expect_true(grepl(expectedTheme, ui, fixed = TRUE))
-
-  expect_no_error(exportStaticApp(
-    result = omopgenerics::emptySummarisedResult(),
-    directory = tdir,
-    theme = NULL,
-    open = FALSE
-  ))
-  ui <- readLines(file.path(tdir, "shiny", "ui.R"))
-  expect_snapshot(cat(ui, sep = "\n"))
-
-  # delete created shiny
-  unlink(file.path(tdir, "shiny"), recursive = TRUE)
+  # not bslib call
+  expect_error(validateTheme('bslib::accordion()'))
 })
 
-test_that("check preprocess file works", {
-  skip_on_cran()
-  # create mock cdm
-  set.seed(123456)
-  cdm <- omock::mockCdmReference() |>
-    omock::mockPerson(nPerson = 100) |>
-    omock::mockObservationPeriod() |>
-    omock::mockConditionOccurrence(recordPerson = 3) |>
-    omock::mockDrugExposure(recordPerson = 4.5) |>
-    omock::mockCohort(
-      numberCohorts = 3, cohortName = c("covid", "tb", "asthma"))
+test_that("default panel", {
+  result <- dplyr::tibble(
+    cdm_name = "mock",
+    cohort_name = "cohort 1",
+    age_group = c(rep("overall", 2), rep("0 to 24", 2)),
+    variable_name = c("concept 1", "concept 2", "concept 1", "concept 2"),
+    variable_level = c("1", "2", "1", "2"),
+    smd = c(0.001, 0.6, NA, 0.05),
+    p = c(0.0001, 0.001, 0.01, 0.13),
+    time = "years",
+    result_type = "custom_result"
+  ) |>
+    omopgenerics::transformToSummarisedResult(
+      group = "cohort_name",
+      strata = "age_group",
+      estimates = c("smd", "p"),
+      settings = c("result_type", "time")
+    )
 
-  # TO BE REMOVED WHEN CohortCharacteristics works with local cdms
-  cdm <- CDMConnector::copyCdmTo(
-    con = duckdb::dbConnect(duckdb::duckdb()), cdm = cdm, schema = "main")
-
-  # generate result set
-  result <- omopgenerics::bind(
-    cdm$cohort |>
-      CohortCharacteristics::summariseCharacteristics(),
-    cdm$cohort |>
-      CohortCharacteristics::summariseCohortAttrition(),
-    cdm$cohort |>
-      CohortCharacteristics::summariseCohortCount(),
-    cdm$cohort |>
-      CohortCharacteristics::summariseCohortOverlap(),
-    cdm$cohort |>
-      CohortCharacteristics::summariseCohortTiming()
-  )
-
-  # with no panelDetails
   tdir <- tempdir()
-  expect_no_error(exportStaticApp(
-    result = result, directory = tdir, open = FALSE
-  ))
-  expect_true(dir.exists(file.path(tdir, "shiny")))
-  expect_true(file.exists(file.path(tdir, "shiny", "data", "preprocess.R")))
-  expect_true(file.exists(file.path(tdir, "shiny", "data", "shinyData.RData")))
-  load(file.path(tdir, "shiny", "data", "shinyData.RData"))
-  savedData <- data
-  savedFilterValues <- filterValues
-  # delete shinyData
-  unlink(file.path(tdir, "shiny", "data", "shinyData.RData"))
-  expect_false(file.exists(file.path(tdir, "shiny", "data", "shinyData.RData")))
-  # create same file file with
-  currentDirectory <- getwd()
-  setwd(file.path(tdir, "shiny"))
-  source(file.path(tdir, "shiny", "data", "preprocess.R"))
-  setwd(currentDirectory)
-  expect_true(file.exists(file.path(tdir, "shiny", "data", "shinyData.RData")))
-  load(file.path(tdir, "shiny", "data", "shinyData.RData"))
-  # settings are in different order
-  removeSettings <- function(x) {
-    purrr::map(x, \(x) {
-      attr(x, "settings") <- NULL
-      return(x)
-    })
-  }
-  expect_identical(removeSettings(savedData), removeSettings(data))
-  expect_identical(savedFilterValues, filterValues)
-  # delete created shiny
+  expect_no_error(exportStaticApp(result = result, directory = tdir))
+  expect_true("shiny" %in% list.files(tdir))
   unlink(file.path(tdir, "shiny"), recursive = TRUE)
 
 })
